@@ -230,9 +230,10 @@ document.write("<input type=\"button\" name=\"QScancel\" value=\"<?php echo _("C
 function quicksave_compose_functions()
 {
 
-    global $quicksave_cookie_days, $quicksave_cookie_hours, $quicksave_cookie_minutes;
-    global $maxCookieLength, $maxCookies, $useMultipleCookies, $maxSingleCookieLength;
-    global $username, $data_dir;
+    global $quicksave_cookie_days, $quicksave_cookie_hours, $quicksave_cookie_minutes,
+           $maxCookieLength, $maxCookies, $useMultipleCookies, $maxSingleCookieLength,
+           $username, $data_dir, $plugins;
+
     $qs_username = preg_replace('/[\.@_]/', '', $username);
 
     if (compatibility_check_sm_version(1, 3))
@@ -261,11 +262,55 @@ var maxCookies = <?php echo $maxCookies ?>;
 
 
 
+<?php /*
+function QuickSave_onError(msg, URL, lineNo)
+{
+
+   // buggy SM installations sometimes have left & right frames
+   // under different servers (usually http vs https).  this is
+   // a workaround to stop javascript errors in such cases, when
+   // QuickSave probably isn't even using the left frame's code
+   // anyway.
+   //
+   // we turn off error checking 
+   if (catchThisError)
+   {
+      dontUseLeftFrame = true;
+      catchThisError = false;
+      return true;
+   }
+//      alert ('your error message is ' + msg);
+//      alert ('your error URL is ' + URL);
+//      alert ('your error line number is ' + lineNo);
+
+
+   // other errors process as usual
+   //
+   return false; 
+
+}
+*/ ?>
+
+
+
 function QuickSave_left_frame_exists()
 {
-	 // this checks to make sure the left frame has loaded...
+	// this checks to make sure the left frame has loaded...
 	var quicksave_exists = false;
 
+
+<?php /*
+        // buggy SM installations sometimes have left & right frames
+        // under different servers (usually http vs https).  this is
+        // a workaround to stop javascript errors in such cases, when
+        // QuickSave probably isn't even using the left frame's code
+        // anyway.
+        //
+        if (dontUseLeftFrame)
+           return false;
+*/ ?>
+ 
+
 	if ( parent.left && parent.left.document.forms )
 	{
 		for ( var i = 0 ; i < parent.left.document.forms.length ; i++ )
@@ -282,6 +327,25 @@ function QuickSave_left_frame_exists()
 }
 
 
+
+<?php /*
+// buggy SM installations sometimes have left & right frames
+// under different servers (usually http vs https).  this is
+// a workaround to stop javascript errors in such cases, when
+// QuickSave probably isn't even using the left frame's code
+// anyway.
+//
+// in order to make this work, we need to purposefully trip
+// this error now, before anything else happens
+//
+var catchThisError = true;
+window.onerror = QuickSave_onError;
+QuickSave_left_frame_exists();
+catchThisError = false;
+*/ ?>
+
+
+
 <?php
 
 
@@ -368,9 +432,44 @@ function QuickSave_swap(from_form, to_form, write_empty)
 			QuickSave_cookie_shove("send_to_bcc=" + escape(document.compose.send_to_bcc.value), expiration);
 		if ( document.compose.subject )
 			QuickSave_cookie_shove("subject=" + escape(document.compose.subject.value), expiration);
-		if ( document.compose.body )
-			QuickSave_cookie_shove("body=" + escape(document.compose.body.value), expiration);
            <?php
+
+           // when using HTML Mail plugin, text is elsewhere
+           //
+           if (in_array('html_mail', $plugins))
+           {
+
+              if (compatibility_check_sm_version(1, 3))
+                 include_once(SM_PATH . 'plugins/html_mail/functions.php');
+              else
+                 include_once('../plugins/html_mail/functions.php');
+
+              if (html_area_is_on_and_is_supported_by_users_browser())
+              {
+                 list($browser, $browserVersion) = getBrowserType();
+
+                 // IE
+                 //
+                 if ($browser == 'Explorer' && $browserVersion >= 5.5)
+                    echo 'if ( document.frames[0].document.body ) QuickSave_cookie_shove("body=" + escape(document.frames[0].document.body.innerHTML), expiration); ';
+
+                 // Gecko
+                 //
+                 else if ($browser == 'Gecko' && $browserVersion >= 20030624)
+                    echo 'if ( document.getElementsByTagName("iframe").item(0).contentDocument.body ) QuickSave_cookie_shove("body=" + escape(document.getElementsByTagName("iframe").item(0).contentDocument.body.innerHTML), expiration);';
+
+              }
+
+              else
+                 echo 'if ( document.compose.body ) QuickSave_cookie_shove("body=" + escape(document.compose.body.value), expiration);';
+
+           }
+           else 
+              echo 'if ( document.compose.body ) QuickSave_cookie_shove("body=" + escape(document.compose.body.value), expiration);';
+
+
+        // when using encryption...
+        //
         } else {
            ?>
 			QuickSave_cookie_shove("send_to=" + QuickSave_encrypt(escape(document.compose.send_to.value)), expiration);
@@ -380,9 +479,42 @@ function QuickSave_swap(from_form, to_form, write_empty)
 			QuickSave_cookie_shove("send_to_bcc=" + QuickSave_encrypt(escape(document.compose.send_to_bcc.value)), expiration);
 		if ( document.compose.subject )
 			QuickSave_cookie_shove("subject=" + QuickSave_encrypt(escape(document.compose.subject.value)), expiration);
-		if ( document.compose.body )
-			QuickSave_cookie_shove("body=" + QuickSave_encrypt(escape(document.compose.body.value)), expiration);
            <?php
+
+
+           // when using HTML Mail plugin, text is elsewhere
+           //
+           if (in_array('html_mail', $plugins))
+           {
+
+              if (compatibility_check_sm_version(1, 3))
+                 include_once(SM_PATH . 'plugins/html_mail/functions.php');
+              else
+                 include_once('../plugins/html_mail/functions.php');
+
+              if (html_area_is_on_and_is_supported_by_users_browser())
+              {
+                 list($browser, $browserVersion) = getBrowserType();
+
+                 // IE
+                 //
+                 if ($browser == 'Explorer' && $browserVersion >= 5.5)
+                    echo 'if ( document.frames[0].document.body ) QuickSave_cookie_shove("body=" + QuickSave_encrypt(escape(document.frames[0].document.body.innerHTML)), expiration);';
+
+                 // Gecko
+                 //
+                 else if ($browser == 'Gecko' && $browserVersion >= 20030624)
+                    echo 'if ( document.getElementsByTagName("iframe").item(0).contentDocument.body ) QuickSave_cookie_shove("body=" + QuickSave_encrypt(escape(document.getElementsByTagName("iframe").item(0).contentDocument.body.innerHTML)), expiration);';
+
+              }
+
+              else
+                 echo 'if ( document.compose.body ) QuickSave_cookie_shove("body=" + QuickSave_encrypt(escape(document.compose.body.value)), expiration);';
+
+           }
+           else
+              echo 'if ( document.compose.body ) QuickSave_cookie_shove("body=" + QuickSave_encrypt(escape(document.compose.body.value)), expiration);';
+
         }
   ?>
 	 	
@@ -1075,6 +1207,12 @@ function trim(stringToTrim)
 
 ?>
 
+   // when composing HTML formatted emails, blank emails 
+   // might have just some junk in them
+   //
+   if (trim(bodyCheck) == "<br>") bodyCheck = "";
+   if (trim(bodyCheck) == "<P>&nbsp;</P>") bodyCheck = "";
+
    var bodyFromPost = "<?php if (isset($_POST['body'])) 
                                 echo str_replace('"', '\'', 
                                      preg_replace("/(\015\012)|(\015)|(\012)/", "", $_POST['body'])) 
